package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.crmf.EncryptedValue;
import cn.com.infosec.asn1.crmf.PKIPublicationInfo;

public class CertifiedKeyPair extends ASN1Encodable {
   private CertOrEncCert certOrEncCert;
   private EncryptedValue privateKey;
   private PKIPublicationInfo publicationInfo;

   private CertifiedKeyPair(ASN1Sequence seq) {
      this.certOrEncCert = CertOrEncCert.getInstance(seq.getObjectAt(0));
      if (seq.size() >= 2) {
         if (seq.size() == 2) {
            ASN1TaggedObject seq1;
            if ((seq1 = ASN1TaggedObject.getInstance(seq.getObjectAt(1))).getTagNo() == 0) {
               this.privateKey = EncryptedValue.getInstance(seq1.getObject());
            } else {
               this.publicationInfo = PKIPublicationInfo.getInstance(seq1.getObject());
            }
         } else {
            this.privateKey = EncryptedValue.getInstance(ASN1TaggedObject.getInstance(seq.getObjectAt(1)));
            this.publicationInfo = PKIPublicationInfo.getInstance(ASN1TaggedObject.getInstance(seq.getObjectAt(2)));
         }
      }

   }

   public static CertifiedKeyPair getInstance(Object o) {
      if (o instanceof CertifiedKeyPair) {
         return (CertifiedKeyPair)o;
      } else if (o instanceof ASN1Sequence) {
         return new CertifiedKeyPair((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public CertOrEncCert getCertOrEncCert() {
      return this.certOrEncCert;
   }

   public EncryptedValue getPrivateKey() {
      return this.privateKey;
   }

   public PKIPublicationInfo getPublicationInfo() {
      return this.publicationInfo;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.certOrEncCert);
      EncryptedValue var2;
      if ((var2 = this.privateKey) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(true, 0, var2);
         var1.add(var3);
      }

      PKIPublicationInfo var4;
      if ((var4 = this.publicationInfo) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(true, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
